Module bitwise_ops

Module bitwise_ops 

Bitwise operations for Arrays

This module provides bitwise operations for integer arrays, including AND, OR, XOR, NOT, and bit shifting operations.

Functions

bitwise_and
Compute the bit-wise AND of two arrays element-wise
bitwise_not
Compute bit-wise NOT (inversion) element-wise
bitwise_or
Compute the bit-wise OR of two arrays element-wise
bitwise_xor
Compute the bit-wise XOR (exclusive OR) of two arrays element-wise
invert
Compute bit-wise inversion element-wise
left_shift
Shift the bits of an integer to the left
left_shift_scalar
Shift the bits of an integer to the left by a scalar amount
right_shift
Shift the bits of an integer to the right
right_shift_scalar
Shift the bits of an integer to the right by a scalar amount