optimal_alignment

Function optimal_alignment 

pub fn optimal_alignment<T>() -> usize
Determine the optimal memory alignment for a given data type

This function calculates the best alignment based on the CPU’s SIMD capabilities and the size of the data type.