pub struct DeviceManager {}Expand description
Device detection and management
Implementations
Sourceimpl DeviceManager
impl DeviceManager
Sourcepub fn new() -> Result<DeviceManager, NdimageError>
pub fn new() -> Result<DeviceManager, NdimageError>
Create a new device manager and detect all available devices
Sourcepub fn get_best_device(&self, requiredmemory: usize) -> Option<(Backend, usize)>
pub fn get_best_device(&self, requiredmemory: usize) -> Option<(Backend, usize)>
Get the best available device for a given workload size
Sourcepub fn get_device_info(
&self,
backend: Backend,
device_id: usize,
) -> Option<&DeviceCapability>
pub fn get_device_info( &self, backend: Backend, device_id: usize, ) -> Option<&DeviceCapability>
Get device capabilities by backend and index
Sourcepub fn is_backend_available(&self, backend: Backend) -> bool
pub fn is_backend_available(&self, backend: Backend) -> bool
Check if a specific backend is available
Sourcepub fn device_count(&self, backend: Backend) -> usize
pub fn device_count(&self, backend: Backend) -> usize
Get the number of devices for a specific backend
Sourcepub fn get_capabilities(&self) -> SystemCapabilities
pub fn get_capabilities(&self) -> SystemCapabilities
Get overall system capabilities