RegionProps

Struct RegionProps 

pub struct RegionProps<T>
where T: Float,
{
Show 20 fields pub label: usize, pub area: usize, pub centroid: (T, T), pub weighted_centroid: (T, T), pub bounding_box: (usize, usize, usize, usize), pub perimeter: T, pub eccentricity: T, pub orientation: T, pub equivalent_diameter: T, pub major_axis_length: T, pub minor_axis_length: T, pub euler_number: i32, pub solidity: T, pub extent: T, pub mean_intensity: T, pub min_intensity: T, pub max_intensity: T, pub hu_moments: [T; 7], pub central_moments: [T; 8], pub normalized_moments: [T; 7],
}
Comprehensive properties of a single labeled region

Fields

label: usize

Label value

area: usize

Number of pixels

centroid: (T, T)

Geometric centroid (row, col)

weighted_centroid: (T, T)

Intensity-weighted centroid (row, col)

bounding_box: (usize, usize, usize, usize)

Bounding box (min_row, min_col, max_row_exclusive, max_col_exclusive)

perimeter: T

Perimeter length (boundary pixel count, 4-connected)

eccentricity: T

Eccentricity of equivalent ellipse (0 = circle, approaching 1 = line)

orientation: T

Orientation angle in radians of major axis

equivalent_diameter: T

Diameter of a circle with the same area

major_axis_length: T

Length of the major axis of the equivalent ellipse

minor_axis_length: T

Length of the minor axis of the equivalent ellipse

euler_number: i32

Euler number: #objects - #holes (4-connected topology)

solidity: T

Solidity: area / convex_hull_area

extent: T

Extent: area / bounding_box_area

mean_intensity: T

Mean intensity

min_intensity: T

Minimum intensity

max_intensity: T

Maximum intensity

hu_moments: [T; 7]

7 Hu invariant moments (translation, scale, rotation invariant)

central_moments: [T; 8]

Raw central moments (mu_00, mu_20, mu_11, mu_02, mu_30, mu_21, mu_12, mu_03)

normalized_moments: [T; 7]

Normalized central moments (nu_20, nu_11, nu_02, nu_30, nu_21, nu_12, nu_03)