pub struct FeatureDescriptor {
pub keypoint: Keypoint,
pub descriptor: Vec<f64>,
}Expand description
A feature descriptor associated with a keypoint.
The descriptor is a fixed-length vector of floating-point values that characterizes the local image neighborhood around a keypoint. Descriptors are normalized to unit length for illumination invariance.
Fields
keypoint: KeypointThe keypoint this descriptor is associated with
descriptor: Vec<f64>The descriptor vector (normalized to unit length)