pub struct ExponentialMovingAverage { /* private fields */ }Expand description
Exponential Moving Average (EMA) filter.
Each new value is blended with the running average: EMA_new = alpha * value + (1 - alpha) * EMA_old
The first pushed value initializes the EMA directly.
Example
use numrs2::new_modules::streaming_stats::ExponentialMovingAverage;
let mut ema = ExponentialMovingAverage::new(0.5).expect("valid smoothing factor");
ema.push(10.0);
assert!((ema.value().expect("EMA has data") - 10.0).abs() < 1e-10);
ema.push(20.0);
assert!((ema.value().expect("EMA has data") - 15.0).abs() < 1e-10);Implementations
Sourceimpl ExponentialMovingAverage
impl ExponentialMovingAverage
Sourcepub fn new(alpha: f64) -> Result<Self>
pub fn new(alpha: f64) -> Result<Self>
Creates a new EMA with the given smoothing factor alpha.
Errors
Returns an error if alpha is not in the interval (0, 1].
Sourcepub fn push(&mut self, value: f64)
pub fn push(&mut self, value: f64)
Pushes a new observation. The first value initializes the EMA; subsequent values are exponentially blended.