pub fn global_thread_pool() -> Arc<ThreadPool> ⓘExpand description
Get the global persistent thread pool
This pool is initialized once and reused across all parallel operations to eliminate thread creation/destruction overhead.
pub fn global_thread_pool() -> Arc<ThreadPool> ⓘGet the global persistent thread pool
This pool is initialized once and reused across all parallel operations to eliminate thread creation/destruction overhead.