Generator

Struct Generator 

pub struct Generator<B: BitGenerator> { /* private fields */ }
Generator for random number streams with modern interface

This class is modeled after NumPy’s Generator class, which is the modern interface for random number generation in NumPy.

Implementations

Source

impl<B: BitGenerator> Generator<B>

pub fn new(bit_generator: B) -> Self

Create a new generator with the given bit generator

pub fn random<T>(&self, shape: &[usize]) -> Result<Array<T>>
where T: Clone + Float + NumCast,

Generate uniform random values in [0, 1)

pub fn integers<T: Clone + PartialOrd + SampleUniform + Into<i64> + TryFrom<i64> + ToPrimitive>( &self, low: T, high: T, shape: &[usize], ) -> Result<Array<T>>
where <T as TryFrom<i64>>::Error: Debug,

Generate integers in the range [low, high)

Arguments
  • low - Lower bound (inclusive)
  • high - Upper bound (exclusive)
  • shape - Shape of the output array
Returns

An array of random integers.

pub fn normal<T: Float + NumCast + Clone + Debug + Display>( &self, mean: T, std: T, shape: &[usize], ) -> Result<Array<T>>

Generate random values from a normal (Gaussian) distribution

pub fn standard_normal<T: Float + NumCast + Clone + Debug + Display>( &self, shape: &[usize], ) -> Result<Array<T>>

Generate a standard normal distribution

pub fn lognormal<T: Float + NumCast + Clone + Debug + Display>( &self, mean: T, sigma: T, shape: &[usize], ) -> Result<Array<T>>

Generate random values from a log-normal distribution

pub fn beta<T: Float + NumCast + Clone + Debug + Display>( &self, a: T, b: T, shape: &[usize], ) -> Result<Array<T>>

Generate random values from a Beta distribution

pub fn chisquare<T: Float + NumCast + Clone + Debug + Display>( &self, df: T, shape: &[usize], ) -> Result<Array<T>>

Generate random values from a Chi-Square distribution

pub fn gamma<T: Float + NumCast + Clone + Debug + Display>( &self, shape_param: T, scale: T, size_shape: &[usize], ) -> Result<Array<T>>

Generate random values from a gamma distribution

pub fn exponential<T: Float + NumCast + Clone + Debug + Display>( &self, scale: T, shape: &[usize], ) -> Result<Array<T>>

Generate random values from an exponential distribution

pub fn weibull<T: Float + NumCast + Clone + Debug + Display>( &self, shape_param: T, scale: T, size_shape: &[usize], ) -> Result<Array<T>>

Generate random values from a Weibull distribution

pub fn uniform<T: Clone + PartialOrd + SampleUniform + ToPrimitive + NumCast>( &self, low: T, high: T, shape: &[usize], ) -> Result<Array<T>>

Generate random values from a uniform distribution

pub fn bernoulli<T: Float + NumCast + Clone + Debug + Display>( &self, p: T, shape: &[usize], ) -> Result<Array<T>>

Generate binary random values with given probability of success

pub fn poisson<T: NumCast + Clone + Debug>( &self, lam: f64, shape: &[usize], ) -> Result<Array<T>>

Generate random values from a Poisson distribution

pub fn binomial<T: NumCast + Clone + Debug>( &self, n: u64, p: f64, shape: &[usize], ) -> Result<Array<T>>

Generate random values from a binomial distribution

pub fn integers_simple<T: Clone + PartialOrd + SampleUniform + NumCast>( &self, low: T, high: T, shape: &[usize], ) -> Result<Array<T>>

Generate integers in a given range

Arguments
  • low - Lower bound (inclusive)
  • high - Upper bound (exclusive)
  • shape - Shape of the output array
Returns

An array of random integers in the specified range.

pub fn bit_generator(&self) -> Result<MutexGuard<'_, B>>

Access the underlying bit generator