Module stride_tricks

Module stride_tricks 

Functions

as_strided
Create a new view into the array with the given shape and strides.
broadcast_arrays
Create views into arrays in a way that broadcasting might occur.
broadcast_to
Broadcast an array to a new shape using stride tricks.
byte_strides
Returns the byte strides of an array.
set_strides
Advanced stride manipulation utilities for NumRS2 arrays.
sliding_window_view
Create a sliding window view of an array.