Module util

Module util 

Enums

MemoryLayout
Memory layout optimization utilities

Functions

astype
Type conversion utilities
broadcast_arrays
Broadcasting utilities
can_cast
Check if a data type can be cast to another data type
can_operate_inplace
Checks if an array can be operated on in-place
common_type
Find the common type that can represent all input types
fast_sum
isscalar
Check if a value is a scalar (0-dimensional)
isscalar_array
Check if a given array is a scalar (0-dimensional array)
optimize_layout
Optimizes the memory layout of an array for a specific operation
parallel_map
Utilities for parallel computation
result_type
Determine the result type of an operation on given types