Bitwise operations for Arrays
This module provides bitwise operations for integer arrays, including AND, OR, XOR, NOT, and bit shifting operations.
Functions
- bitwise_
and - Compute the bit-wise AND of two arrays element-wise
- bitwise_
not - Compute bit-wise NOT (inversion) element-wise
- bitwise_
or - Compute the bit-wise OR of two arrays element-wise
- bitwise_
xor - Compute the bit-wise XOR (exclusive OR) of two arrays element-wise
- invert
- Compute bit-wise inversion element-wise
- left_
shift - Shift the bits of an integer to the left
- left_
shift_ scalar - Shift the bits of an integer to the left by a scalar amount
- right_
shift - Shift the bits of an integer to the right
- right_
shift_ scalar - Shift the bits of an integer to the right by a scalar amount