NumRS2 Error System
This module provides both the new hierarchical error system and backward compatibility with the existing flat error structure.
Re-exports
pub use computation::ComputationError;pub use context::ErrorContext;pub use context::ErrorLocation;pub use context::ErrorSeverity;pub use context::OperationContext;pub use core::CoreError;pub use io::IOError;pub use memory::MemoryError;pub use super::computation::*;pub use super::context::*;pub use super::core::*;pub use super::io::*;pub use super::memory::*;
Modules
- computation
- Computation and numerical errors - instability, convergence, overflow
- context
- Error context and metadata for enhanced error reporting
- core
- Core library errors - shape mismatches, indexing, basic operations
- io
- I/O and serialization errors - file operations, network, data format issues
- memory
- Memory management errors - allocation failures, out of memory, corruption
- prelude
Enums
- Error
Category - NumRs2
Error - NumRS2 error types (legacy structure for backward compatibility)
Type Aliases
- Context
Result - Enhanced result type with context
- Result
- Result type for NumRS2 operations