pub struct ErrorStateGuard { /* private fields */ }Expand description
Context manager for temporarily changing error handling behavior
Similar to NumPy’s errstate context manager. This allows you to temporarily change the error handling behavior and automatically restore it when done.
Examples
use numrs2::error_handling::{errstate, ErrorAction};
{
let _guard = errstate()
.divide(ErrorAction::Ignore)
.over(ErrorAction::Raise)
.enter();
// Operations here will ignore division by zero and raise on overflow
// Error state is automatically restored when _guard goes out of scope
}Trait Implementations
Sourceimpl Drop for ErrorStateGuard
impl Drop for ErrorStateGuard