Function bincount
Source pub fn bincount(
array: &Array<usize>,
minlength: Option<usize>,
) -> Result<Array<usize>>
Count occurrences of each value in array of non-negative ints
Parameters
array - Input array of non-negative integers
minlength - Minimum number of bins for output array
Returns
Array where element i is the count of occurrences of i in the input array