pub struct QuantumFourierTransform;Expand description
Quantum Fourier Transform (QFT)
Implements the quantum analogue of the discrete Fourier transform. The QFT is a key component of many quantum algorithms including Shor’s algorithm and quantum phase estimation.
Mathematical Background
QFT maps |j⟩ → (1/√N) Σₖ exp(2πijk/N)|k⟩ where N = 2ⁿ
Implementations
Sourceimpl QuantumFourierTransform
impl QuantumFourierTransform
Sourcepub fn apply<T>(circuit: &mut QuantumCircuit<T>) -> Result<()>
pub fn apply<T>(circuit: &mut QuantumCircuit<T>) -> Result<()>