Function benchmark_threshold
Source pub fn benchmark_threshold<F>(element_cost: F) -> usize
Benchmark to determine the optimal threshold for the current hardware
Arguments
element_cost - A function that simulates the cost of processing a single element
Returns
The optimal threshold determined by benchmarking