Functions
- as_
strided - Create a new view into the array with the given shape and strides.
- broadcast_
arrays - Create views into arrays in a way that broadcasting might occur.
- broadcast_
to - Broadcast an array to a new shape using stride tricks.
- byte_
strides - Returns the byte strides of an array.
- set_
strides - Advanced stride manipulation utilities for NumRS2 arrays.
- sliding_
window_ view - Create a sliding window view of an array.