Enums
- Memory
Layout - Memory layout optimization utilities
Functions
- astype
- Type conversion utilities
- broadcast_
arrays - Broadcasting utilities
- can_
cast - Check if a data type can be cast to another data type
- can_
operate_ inplace - Checks if an array can be operated on in-place
- common_
type - Find the common type that can represent all input types
- fast_
sum - isscalar
- Check if a value is a scalar (0-dimensional)
- isscalar_
array - Check if a given array is a scalar (0-dimensional array)
- optimize_
layout - Optimizes the memory layout of an array for a specific operation
- parallel_
map - Utilities for parallel computation
- result_
type - Determine the result type of an operation on given types